@@ -9,12 +9,16 @@ class MyCli(Cli):
         Cli.__init__(self, ".my_cli.history", "Hello everybody")
         self.set_prompt("MyCli> ")
 
-        self.register_item(CliItem("my_item"))
+        self.register_item(CliItem("my_item", categories=["basic"]))
         self.register_item(CliItem("item", None, None, True, [CliSysPathItem()]))
-        self.register_item(CliItem("bla", self.bla))
-        self.register_item(CliItem("foo", self.foo))
+        self.register_item(CliItem("bla", self.bla, categories=["basic", "ext"]))
+        self.register_item(CliItem("foo", self.foo, categories=["ext"]))
+        self.register_item(CliItem("args", self.args, categories=["basic"]))
         self.register_item(CliHelper.create_help_item(self))
 
+        self.enable_category("basic")
+        self.disable_category("ext")
+
     @Cli.obs.on("initialized")
     def initialized(self):
         print "on_initialized"
@@ -38,6 +42,13 @@ class MyCli(Cli):
         """some stupid command with wrong help"""
         print "foooo"
 
+    def args(self, item, args, line_input):
+        """
+            arguments: [args...]
+            description: print it's arguments
+        """
+        print args
+
 
 if __name__ == "__main__":
     my_cli = MyCli()
